@@ -2,7 +2,7 @@ from holour.msg.geometry import Vector3, Pose, Poses
 from holour.msg.status import Status
 from holour.msg.force_torque import ForceTorque
 from holour.msg.script import Script, WaypointConfig
-from holour.msg.operation import Operation
-from holour.msg.product import Product
 from holour.msg.task import Task
-from holour.msg.assembly import AddTask, MoveOperation, CompleteOperation, Destination
+from holour.msg.product import Product
+from holour.msg.process import Process
+from holour.msg.assembly import AddTask, MoveOperation, CompleteOperation, Destination, ConfirmNeeded
